var annotated_dup =
[
    [ "itimerspec", "structitimerspec.html", null ],
    [ "pw_array", "structpw__array.html", "structpw__array" ],
    [ "pw_buffer", "structpw__buffer.html", "structpw__buffer" ],
    [ "pw_buffers", "structpw__buffers.html", "structpw__buffers" ],
    [ "pw_client", "structpw__client.html", null ],
    [ "pw_client_endpoint", "structpw__client__endpoint.html", null ],
    [ "pw_client_endpoint_events", "structpw__client__endpoint__events.html", "structpw__client__endpoint__events" ],
    [ "pw_client_endpoint_methods", "structpw__client__endpoint__methods.html", "structpw__client__endpoint__methods" ],
    [ "pw_client_events", "structpw__client__events.html", "structpw__client__events" ],
    [ "pw_client_info", "structpw__client__info.html", "structpw__client__info" ],
    [ "pw_client_methods", "structpw__client__methods.html", "structpw__client__methods" ],
    [ "pw_client_node", "structpw__client__node.html", null ],
    [ "pw_client_node_buffer", "structpw__client__node__buffer.html", "structpw__client__node__buffer" ],
    [ "pw_client_node_events", "structpw__client__node__events.html", "structpw__client__node__events" ],
    [ "pw_client_node_methods", "structpw__client__node__methods.html", "structpw__client__node__methods" ],
    [ "pw_client_session", "structpw__client__session.html", null ],
    [ "pw_client_session_events", "structpw__client__session__events.html", "structpw__client__session__events" ],
    [ "pw_client_session_methods", "structpw__client__session__methods.html", "structpw__client__session__methods" ],
    [ "pw_context", "structpw__context.html", null ],
    [ "pw_context_events", "structpw__context__events.html", "structpw__context__events" ],
    [ "pw_control", "structpw__control.html", null ],
    [ "pw_control_events", "structpw__control__events.html", "structpw__control__events" ],
    [ "pw_core", "structpw__core.html", null ],
    [ "pw_core_events", "structpw__core__events.html", "structpw__core__events" ],
    [ "pw_core_info", "structpw__core__info.html", "structpw__core__info" ],
    [ "pw_core_methods", "structpw__core__methods.html", "structpw__core__methods" ],
    [ "pw_data_loop", "structpw__data__loop.html", null ],
    [ "pw_data_loop_events", "structpw__data__loop__events.html", "structpw__data__loop__events" ],
    [ "pw_device", "structpw__device.html", null ],
    [ "pw_device_events", "structpw__device__events.html", "structpw__device__events" ],
    [ "pw_device_info", "structpw__device__info.html", "structpw__device__info" ],
    [ "pw_device_methods", "structpw__device__methods.html", "structpw__device__methods" ],
    [ "pw_endpoint", "structpw__endpoint.html", null ],
    [ "pw_endpoint_events", "structpw__endpoint__events.html", "structpw__endpoint__events" ],
    [ "pw_endpoint_info", "structpw__endpoint__info.html", "structpw__endpoint__info" ],
    [ "pw_endpoint_link", "structpw__endpoint__link.html", null ],
    [ "pw_endpoint_link_events", "structpw__endpoint__link__events.html", "structpw__endpoint__link__events" ],
    [ "pw_endpoint_link_info", "structpw__endpoint__link__info.html", "structpw__endpoint__link__info" ],
    [ "pw_endpoint_link_methods", "structpw__endpoint__link__methods.html", "structpw__endpoint__link__methods" ],
    [ "pw_endpoint_methods", "structpw__endpoint__methods.html", "structpw__endpoint__methods" ],
    [ "pw_endpoint_stream", "structpw__endpoint__stream.html", null ],
    [ "pw_endpoint_stream_events", "structpw__endpoint__stream__events.html", "structpw__endpoint__stream__events" ],
    [ "pw_endpoint_stream_info", "structpw__endpoint__stream__info.html", "structpw__endpoint__stream__info" ],
    [ "pw_endpoint_stream_methods", "structpw__endpoint__stream__methods.html", "structpw__endpoint__stream__methods" ],
    [ "pw_export_type", "structpw__export__type.html", "structpw__export__type" ],
    [ "pw_factory", "structpw__factory.html", null ],
    [ "pw_factory_events", "structpw__factory__events.html", "structpw__factory__events" ],
    [ "pw_factory_info", "structpw__factory__info.html", "structpw__factory__info" ],
    [ "pw_factory_methods", "structpw__factory__methods.html", "structpw__factory__methods" ],
    [ "pw_filter", "structpw__filter.html", null ],
    [ "pw_filter_events", "structpw__filter__events.html", "structpw__filter__events" ],
    [ "pw_global", "structpw__global.html", null ],
    [ "pw_global_events", "structpw__global__events.html", "structpw__global__events" ],
    [ "pw_impl_client", "structpw__impl__client.html", null ],
    [ "pw_impl_client_events", "structpw__impl__client__events.html", "structpw__impl__client__events" ],
    [ "pw_impl_core", "structpw__impl__core.html", null ],
    [ "pw_impl_core_events", "structpw__impl__core__events.html", "structpw__impl__core__events" ],
    [ "pw_impl_device", "structpw__impl__device.html", null ],
    [ "pw_impl_device_events", "structpw__impl__device__events.html", "structpw__impl__device__events" ],
    [ "pw_impl_factory", "structpw__impl__factory.html", null ],
    [ "pw_impl_factory_events", "structpw__impl__factory__events.html", "structpw__impl__factory__events" ],
    [ "pw_impl_factory_implementation", "structpw__impl__factory__implementation.html", "structpw__impl__factory__implementation" ],
    [ "pw_impl_link", "structpw__impl__link.html", null ],
    [ "pw_impl_link_events", "structpw__impl__link__events.html", "structpw__impl__link__events" ],
    [ "pw_impl_metadata", "structpw__impl__metadata.html", null ],
    [ "pw_impl_metadata_events", "structpw__impl__metadata__events.html", "structpw__impl__metadata__events" ],
    [ "pw_impl_module", "structpw__impl__module.html", null ],
    [ "pw_impl_module_events", "structpw__impl__module__events.html", "structpw__impl__module__events" ],
    [ "pw_impl_node", "structpw__impl__node.html", null ],
    [ "pw_impl_node_events", "structpw__impl__node__events.html", "structpw__impl__node__events" ],
    [ "pw_impl_port", "structpw__impl__port.html", null ],
    [ "pw_impl_port_events", "structpw__impl__port__events.html", "structpw__impl__port__events" ],
    [ "pw_link", "structpw__link.html", null ],
    [ "pw_link_events", "structpw__link__events.html", "structpw__link__events" ],
    [ "pw_link_info", "structpw__link__info.html", "structpw__link__info" ],
    [ "pw_link_methods", "structpw__link__methods.html", "structpw__link__methods" ],
    [ "pw_loop", "structpw__loop.html", "structpw__loop" ],
    [ "pw_main_loop", "structpw__main__loop.html", null ],
    [ "pw_main_loop_events", "structpw__main__loop__events.html", "structpw__main__loop__events" ],
    [ "pw_map", "structpw__map.html", "structpw__map" ],
    [ "pw_map_range", "structpw__map__range.html", "structpw__map__range" ],
    [ "pw_memblock", "structpw__memblock.html", "structpw__memblock" ],
    [ "pw_memchunk", "structpw__memchunk.html", null ],
    [ "pw_memmap", "structpw__memmap.html", "structpw__memmap" ],
    [ "pw_mempool", "structpw__mempool.html", null ],
    [ "pw_mempool_events", "structpw__mempool__events.html", "structpw__mempool__events" ],
    [ "pw_metadata", "structpw__metadata.html", null ],
    [ "pw_metadata_events", "structpw__metadata__events.html", "structpw__metadata__events" ],
    [ "pw_metadata_methods", "structpw__metadata__methods.html", "structpw__metadata__methods" ],
    [ "pw_module", "structpw__module.html", null ],
    [ "pw_module_events", "structpw__module__events.html", "structpw__module__events" ],
    [ "pw_module_info", "structpw__module__info.html", "structpw__module__info" ],
    [ "pw_module_methods", "structpw__module__methods.html", "structpw__module__methods" ],
    [ "pw_node", "structpw__node.html", null ],
    [ "pw_node_events", "structpw__node__events.html", "structpw__node__events" ],
    [ "pw_node_info", "structpw__node__info.html", "structpw__node__info" ],
    [ "pw_node_methods", "structpw__node__methods.html", "structpw__node__methods" ],
    [ "pw_permission", "structpw__permission.html", "structpw__permission" ],
    [ "pw_port", "structpw__port.html", null ],
    [ "pw_port_events", "structpw__port__events.html", "structpw__port__events" ],
    [ "pw_port_info", "structpw__port__info.html", "structpw__port__info" ],
    [ "pw_port_methods", "structpw__port__methods.html", "structpw__port__methods" ],
    [ "pw_profiler", "structpw__profiler.html", null ],
    [ "pw_profiler_events", "structpw__profiler__events.html", "structpw__profiler__events" ],
    [ "pw_profiler_methods", "structpw__profiler__methods.html", "structpw__profiler__methods" ],
    [ "pw_properties", "structpw__properties.html", "structpw__properties" ],
    [ "pw_protocol", "structpw__protocol.html", null ],
    [ "pw_protocol_client", "structpw__protocol__client.html", "structpw__protocol__client" ],
    [ "pw_protocol_events", "structpw__protocol__events.html", "structpw__protocol__events" ],
    [ "pw_protocol_implementation", "structpw__protocol__implementation.html", "structpw__protocol__implementation" ],
    [ "pw_protocol_marshal", "structpw__protocol__marshal.html", "structpw__protocol__marshal" ],
    [ "pw_protocol_native_demarshal", "structpw__protocol__native__demarshal.html", "structpw__protocol__native__demarshal" ],
    [ "pw_protocol_native_ext", "structpw__protocol__native__ext.html", "structpw__protocol__native__ext" ],
    [ "pw_protocol_native_message", "structpw__protocol__native__message.html", "structpw__protocol__native__message" ],
    [ "pw_protocol_server", "structpw__protocol__server.html", "structpw__protocol__server" ],
    [ "pw_proxy", "structpw__proxy.html", null ],
    [ "pw_proxy_events", "structpw__proxy__events.html", "structpw__proxy__events" ],
    [ "pw_registry", "structpw__registry.html", null ],
    [ "pw_registry_events", "structpw__registry__events.html", "structpw__registry__events" ],
    [ "pw_registry_methods", "structpw__registry__methods.html", "structpw__registry__methods" ],
    [ "pw_resource", "structpw__resource.html", null ],
    [ "pw_resource_events", "structpw__resource__events.html", "structpw__resource__events" ],
    [ "pw_session", "structpw__session.html", null ],
    [ "pw_session_events", "structpw__session__events.html", "structpw__session__events" ],
    [ "pw_session_info", "structpw__session__info.html", "structpw__session__info" ],
    [ "pw_session_methods", "structpw__session__methods.html", "structpw__session__methods" ],
    [ "pw_stream", "structpw__stream.html", null ],
    [ "pw_stream_control", "structpw__stream__control.html", "structpw__stream__control" ],
    [ "pw_stream_events", "structpw__stream__events.html", "structpw__stream__events" ],
    [ "pw_thread_loop", "structpw__thread__loop.html", null ],
    [ "pw_thread_loop_events", "structpw__thread__loop__events.html", "structpw__thread__loop__events" ],
    [ "pw_time", "structpw__time.html", "structpw__time" ],
    [ "pw_work_queue", "structpw__work__queue.html", null ],
    [ "pwtest_context", "structpwtest__context.html", null ],
    [ "pwtest_spa_plugin", "structpwtest__spa__plugin.html", "structpwtest__spa__plugin" ],
    [ "pwtest_suite", "structpwtest__suite.html", null ],
    [ "pwtest_test", "structpwtest__test.html", null ],
    [ "spa_audio_aec", "structspa__audio__aec.html", "structspa__audio__aec" ],
    [ "spa_audio_aec_events", "structspa__audio__aec__events.html", "structspa__audio__aec__events" ],
    [ "spa_audio_aec_info", "structspa__audio__aec__info.html", "structspa__audio__aec__info" ],
    [ "spa_audio_aec_methods", "structspa__audio__aec__methods.html", "structspa__audio__aec__methods" ],
    [ "spa_audio_info", "structspa__audio__info.html", "structspa__audio__info" ],
    [ "spa_audio_info_dsd", "structspa__audio__info__dsd.html", "structspa__audio__info__dsd" ],
    [ "spa_audio_info_dsp", "structspa__audio__info__dsp.html", "structspa__audio__info__dsp" ],
    [ "spa_audio_info_iec958", "structspa__audio__info__iec958.html", "structspa__audio__info__iec958" ],
    [ "spa_audio_info_raw", "structspa__audio__info__raw.html", "structspa__audio__info__raw" ],
    [ "spa_audio_layout_info", "structspa__audio__layout__info.html", "structspa__audio__layout__info" ],
    [ "spa_buffer", "structspa__buffer.html", "structspa__buffer" ],
    [ "spa_buffer_alloc_info", "structspa__buffer__alloc__info.html", "structspa__buffer__alloc__info" ],
    [ "spa_callbacks", "structspa__callbacks.html", "structspa__callbacks" ],
    [ "spa_chunk", "structspa__chunk.html", "structspa__chunk" ],
    [ "spa_command", "structspa__command.html", "structspa__command" ],
    [ "spa_command_body", "structspa__command__body.html", "structspa__command__body" ],
    [ "spa_cpu", "structspa__cpu.html", "structspa__cpu" ],
    [ "spa_cpu_methods", "structspa__cpu__methods.html", "structspa__cpu__methods" ],
    [ "spa_data", "structspa__data.html", "structspa__data" ],
    [ "spa_dbus", "structspa__dbus.html", "structspa__dbus" ],
    [ "spa_dbus_connection", "structspa__dbus__connection.html", "structspa__dbus__connection" ],
    [ "spa_dbus_connection_events", "structspa__dbus__connection__events.html", "structspa__dbus__connection__events" ],
    [ "spa_dbus_methods", "structspa__dbus__methods.html", "structspa__dbus__methods" ],
    [ "spa_device", "structspa__device.html", "structspa__device" ],
    [ "spa_device_events", "structspa__device__events.html", "structspa__device__events" ],
    [ "spa_device_info", "structspa__device__info.html", "structspa__device__info" ],
    [ "spa_device_methods", "structspa__device__methods.html", "structspa__device__methods" ],
    [ "spa_device_object_info", "structspa__device__object__info.html", "structspa__device__object__info" ],
    [ "spa_dict", "structspa__dict.html", "structspa__dict" ],
    [ "spa_dict_item", "structspa__dict__item.html", "structspa__dict__item" ],
    [ "spa_dll", "structspa__dll.html", "structspa__dll" ],
    [ "spa_event", "structspa__event.html", "structspa__event" ],
    [ "spa_event_body", "structspa__event__body.html", "structspa__event__body" ],
    [ "spa_fraction", "structspa__fraction.html", "structspa__fraction" ],
    [ "spa_graph", "structspa__graph.html", "structspa__graph" ],
    [ "spa_graph_link", "structspa__graph__link.html", "structspa__graph__link" ],
    [ "spa_graph_node", "structspa__graph__node.html", "structspa__graph__node" ],
    [ "spa_graph_node_callbacks", "structspa__graph__node__callbacks.html", "structspa__graph__node__callbacks" ],
    [ "spa_graph_port", "structspa__graph__port.html", "structspa__graph__port" ],
    [ "spa_graph_state", "structspa__graph__state.html", "structspa__graph__state" ],
    [ "spa_handle", "structspa__handle.html", "structspa__handle" ],
    [ "spa_handle_factory", "structspa__handle__factory.html", "structspa__handle__factory" ],
    [ "spa_hook", "structspa__hook.html", "structspa__hook" ],
    [ "spa_hook_list", "structspa__hook__list.html", "structspa__hook__list" ],
    [ "spa_i18n", "structspa__i18n.html", "structspa__i18n" ],
    [ "spa_i18n_methods", "structspa__i18n__methods.html", "structspa__i18n__methods" ],
    [ "spa_interface", "structspa__interface.html", "structspa__interface" ],
    [ "spa_interface_info", "structspa__interface__info.html", "structspa__interface__info" ],
    [ "spa_io_buffers", "structspa__io__buffers.html", "structspa__io__buffers" ],
    [ "spa_io_clock", "structspa__io__clock.html", "structspa__io__clock" ],
    [ "spa_io_latency", "structspa__io__latency.html", "structspa__io__latency" ],
    [ "spa_io_memory", "structspa__io__memory.html", "structspa__io__memory" ],
    [ "spa_io_position", "structspa__io__position.html", "structspa__io__position" ],
    [ "spa_io_range", "structspa__io__range.html", "structspa__io__range" ],
    [ "spa_io_rate_match", "structspa__io__rate__match.html", "structspa__io__rate__match" ],
    [ "spa_io_segment", "structspa__io__segment.html", "structspa__io__segment" ],
    [ "spa_io_segment_bar", "structspa__io__segment__bar.html", "structspa__io__segment__bar" ],
    [ "spa_io_segment_video", "structspa__io__segment__video.html", "structspa__io__segment__video" ],
    [ "spa_io_sequence", "structspa__io__sequence.html", "structspa__io__sequence" ],
    [ "spa_io_video_size", "structspa__io__video__size.html", "structspa__io__video__size" ],
    [ "spa_json", "structspa__json.html", "structspa__json" ],
    [ "spa_latency_info", "structspa__latency__info.html", "structspa__latency__info" ],
    [ "spa_list", "structspa__list.html", "structspa__list" ],
    [ "spa_log", "structspa__log.html", "structspa__log" ],
    [ "spa_log_methods", "structspa__log__methods.html", "structspa__log__methods" ],
    [ "spa_log_topic", "structspa__log__topic.html", "structspa__log__topic" ],
    [ "spa_loop", "structspa__loop.html", "structspa__loop" ],
    [ "spa_loop_control", "structspa__loop__control.html", "structspa__loop__control" ],
    [ "spa_loop_control_hooks", "structspa__loop__control__hooks.html", "structspa__loop__control__hooks" ],
    [ "spa_loop_control_methods", "structspa__loop__control__methods.html", "structspa__loop__control__methods" ],
    [ "spa_loop_methods", "structspa__loop__methods.html", "structspa__loop__methods" ],
    [ "spa_loop_utils", "structspa__loop__utils.html", "structspa__loop__utils" ],
    [ "spa_loop_utils_methods", "structspa__loop__utils__methods.html", "structspa__loop__utils__methods" ],
    [ "spa_meta", "structspa__meta.html", "structspa__meta" ],
    [ "spa_meta_bitmap", "structspa__meta__bitmap.html", "structspa__meta__bitmap" ],
    [ "spa_meta_busy", "structspa__meta__busy.html", "structspa__meta__busy" ],
    [ "spa_meta_control", "structspa__meta__control.html", "structspa__meta__control" ],
    [ "spa_meta_cursor", "structspa__meta__cursor.html", "structspa__meta__cursor" ],
    [ "spa_meta_header", "structspa__meta__header.html", "structspa__meta__header" ],
    [ "spa_meta_region", "structspa__meta__region.html", "structspa__meta__region" ],
    [ "spa_meta_videotransform", "structspa__meta__videotransform.html", "structspa__meta__videotransform" ],
    [ "spa_node", "structspa__node.html", "structspa__node" ],
    [ "spa_node_callbacks", "structspa__node__callbacks.html", "structspa__node__callbacks" ],
    [ "spa_node_events", "structspa__node__events.html", "structspa__node__events" ],
    [ "spa_node_info", "structspa__node__info.html", "structspa__node__info" ],
    [ "spa_node_methods", "structspa__node__methods.html", "structspa__node__methods" ],
    [ "spa_param_info", "structspa__param__info.html", "structspa__param__info" ],
    [ "spa_plugin_loader", "structspa__plugin__loader.html", "structspa__plugin__loader" ],
    [ "spa_plugin_loader_methods", "structspa__plugin__loader__methods.html", "structspa__plugin__loader__methods" ],
    [ "spa_pod", "structspa__pod.html", "structspa__pod" ],
    [ "spa_pod_array", "structspa__pod__array.html", "structspa__pod__array" ],
    [ "spa_pod_array_body", "structspa__pod__array__body.html", "structspa__pod__array__body" ],
    [ "spa_pod_bitmap", "structspa__pod__bitmap.html", "structspa__pod__bitmap" ],
    [ "spa_pod_bool", "structspa__pod__bool.html", "structspa__pod__bool" ],
    [ "spa_pod_builder", "structspa__pod__builder.html", "structspa__pod__builder" ],
    [ "spa_pod_builder_callbacks", "structspa__pod__builder__callbacks.html", "structspa__pod__builder__callbacks" ],
    [ "spa_pod_builder_state", "structspa__pod__builder__state.html", "structspa__pod__builder__state" ],
    [ "spa_pod_bytes", "structspa__pod__bytes.html", "structspa__pod__bytes" ],
    [ "spa_pod_choice", "structspa__pod__choice.html", "structspa__pod__choice" ],
    [ "spa_pod_choice_body", "structspa__pod__choice__body.html", "structspa__pod__choice__body" ],
    [ "spa_pod_control", "structspa__pod__control.html", "structspa__pod__control" ],
    [ "spa_pod_double", "structspa__pod__double.html", "structspa__pod__double" ],
    [ "spa_pod_dynamic_builder", "structspa__pod__dynamic__builder.html", "structspa__pod__dynamic__builder" ],
    [ "spa_pod_fd", "structspa__pod__fd.html", "structspa__pod__fd" ],
    [ "spa_pod_float", "structspa__pod__float.html", "structspa__pod__float" ],
    [ "spa_pod_fraction", "structspa__pod__fraction.html", "structspa__pod__fraction" ],
    [ "spa_pod_frame", "structspa__pod__frame.html", "structspa__pod__frame" ],
    [ "spa_pod_id", "structspa__pod__id.html", "structspa__pod__id" ],
    [ "spa_pod_int", "structspa__pod__int.html", "structspa__pod__int" ],
    [ "spa_pod_long", "structspa__pod__long.html", "structspa__pod__long" ],
    [ "spa_pod_object", "structspa__pod__object.html", "structspa__pod__object" ],
    [ "spa_pod_object_body", "structspa__pod__object__body.html", "structspa__pod__object__body" ],
    [ "spa_pod_parser", "structspa__pod__parser.html", "structspa__pod__parser" ],
    [ "spa_pod_parser_state", "structspa__pod__parser__state.html", "structspa__pod__parser__state" ],
    [ "spa_pod_pointer", "structspa__pod__pointer.html", "structspa__pod__pointer" ],
    [ "spa_pod_pointer_body", "structspa__pod__pointer__body.html", "structspa__pod__pointer__body" ],
    [ "spa_pod_prop", "structspa__pod__prop.html", "structspa__pod__prop" ],
    [ "spa_pod_rectangle", "structspa__pod__rectangle.html", "structspa__pod__rectangle" ],
    [ "spa_pod_sequence", "structspa__pod__sequence.html", "structspa__pod__sequence" ],
    [ "spa_pod_sequence_body", "structspa__pod__sequence__body.html", "structspa__pod__sequence__body" ],
    [ "spa_pod_string", "structspa__pod__string.html", "structspa__pod__string" ],
    [ "spa_pod_struct", "structspa__pod__struct.html", "structspa__pod__struct" ],
    [ "spa_point", "structspa__point.html", "structspa__point" ],
    [ "spa_poll_event", "structspa__poll__event.html", "structspa__poll__event" ],
    [ "spa_port_info", "structspa__port__info.html", "structspa__port__info" ],
    [ "spa_process_latency_info", "structspa__process__latency__info.html", "structspa__process__latency__info" ],
    [ "spa_rectangle", "structspa__rectangle.html", "structspa__rectangle" ],
    [ "spa_region", "structspa__region.html", "structspa__region" ],
    [ "spa_result_device_params", "structspa__result__device__params.html", "structspa__result__device__params" ],
    [ "spa_result_device_params_data", "structspa__result__device__params__data.html", "structspa__result__device__params__data" ],
    [ "spa_result_node_error", "structspa__result__node__error.html", "structspa__result__node__error" ],
    [ "spa_result_node_params", "structspa__result__node__params.html", "structspa__result__node__params" ],
    [ "spa_result_node_params_data", "structspa__result__node__params__data.html", "structspa__result__node__params__data" ],
    [ "spa_ringbuffer", "structspa__ringbuffer.html", "structspa__ringbuffer" ],
    [ "spa_source", "structspa__source.html", "structspa__source" ],
    [ "spa_support", "structspa__support.html", "structspa__support" ],
    [ "spa_system", "structspa__system.html", "structspa__system" ],
    [ "spa_system_methods", "structspa__system__methods.html", "structspa__system__methods" ],
    [ "spa_thread", "structspa__thread.html", null ],
    [ "spa_thread_utils", "structspa__thread__utils.html", "structspa__thread__utils" ],
    [ "spa_thread_utils_methods", "structspa__thread__utils__methods.html", "structspa__thread__utils__methods" ],
    [ "spa_type_info", "structspa__type__info.html", "structspa__type__info" ],
    [ "spa_video_colorimetry", "structspa__video__colorimetry.html", "structspa__video__colorimetry" ],
    [ "spa_video_info", "structspa__video__info.html", "structspa__video__info" ],
    [ "spa_video_info_dsp", "structspa__video__info__dsp.html", "structspa__video__info__dsp" ],
    [ "spa_video_info_h264", "structspa__video__info__h264.html", "structspa__video__info__h264" ],
    [ "spa_video_info_mjpg", "structspa__video__info__mjpg.html", "structspa__video__info__mjpg" ],
    [ "spa_video_info_raw", "structspa__video__info__raw.html", "structspa__video__info__raw" ]
];